layout

Function layout 

pub fn layout<'a>(data_type: &'a DataType, path: &str) -> Result<Layout<'a>>
The layout of one type.

Errors

Returns a Invariant::Unsupported violation for a type this crate cannot check, which is the same thing as a type iris cannot carry.